@@ -20,9 +20,9 @@ Utilities shared by dxpy modules.
 
 from __future__ import (print_function, unicode_literals)
 
-import os, json, collections, concurrent.futures, traceback, time, gc
+import os, json, collections, concurrent.futures, traceback, sys, time, gc
 import dateutil.parser
-from .exec_utils import run, convert_handlers_to_dxlinks, parse_args_as_job_input, entry_point
+from .exec_utils import run, convert_handlers_to_dxlinks, parse_args_as_job_input, entry_point, DXJSONEncoder
 from .thread_pool import PrioritizingThreadPool
 from .. import logger
 from ..compat import basestring
